@@ -14,6 +14,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import sys
+import warnings
 
 from oslo_log import log as logging
 from oslo_reports import guru_meditation_report as gmr
@@ -21,7 +22,6 @@ from oslo_reports import guru_meditation_report as gmr
 from designate.agent import service as agent_service
 import designate.conf
 from designate import heartbeat_emitter
-from designate import hookpoints
 from designate import service
 from designate import utils
 from designate import version
@@ -36,7 +36,9 @@ def main():
     logging.setup(CONF, 'designate')
     gmr.TextGuruMeditation.setup_autorun(version)
 
-    hookpoints.log_hook_setup()
+    warnings.warn('The designate agent process is deprecated as of the '
+                  'Antelope (2023.1) release and will be removed in the '
+                  '"C" release.', DeprecationWarning)
 
     server = agent_service.Service()
     heartbeat = heartbeat_emitter.get_heartbeat_emitter(server.service_name)
