@@ -17,10 +17,9 @@ from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate.conf.mdns import DEFAULT_MDNS_PORT
+from designate import dnsmiddleware
 from designate import dnsutils
 from designate.mdns import handler
-from designate.mdns import notify
-from designate.mdns import xfr
 from designate import service
 from designate import storage
 from designate import utils
@@ -29,20 +28,15 @@ LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
 
 
-class Service(service.RPCService):
+class Service(service.Service):
     _dns_default_port = DEFAULT_MDNS_PORT
 
     def __init__(self):
         self._storage = None
 
         super(Service, self).__init__(
-            self.service_name, cfg.CONF['service:mdns'].topic,
-            threads=cfg.CONF['service:mdns'].threads,
+            self.service_name, threads=cfg.CONF['service:mdns'].threads,
         )
-        self.override_endpoints(
-            [notify.NotifyEndpoint(self.tg), xfr.XfrEndpoint(self.tg)]
-        )
-
         self.dns_service = service.DNSService(
             self.dns_application, self.tg,
             cfg.CONF['service:mdns'].listen,
@@ -61,9 +55,7 @@ class Service(service.RPCService):
     @property
     def storage(self):
         if not self._storage:
-            self._storage = storage.get_storage(
-                CONF['service:mdns'].storage_driver
-            )
+            self._storage = storage.get_storage()
         return self._storage
 
     @property
@@ -76,8 +68,10 @@ class Service(service.RPCService):
         # Create an instance of the RequestHandler class and wrap with
         # necessary middleware.
         application = handler.RequestHandler(self.storage, self.tg)
-        application = dnsutils.TsigInfoMiddleware(application, self.storage)
-        application = dnsutils.SerializationMiddleware(
+        application = dnsmiddleware.TsigInfoMiddleware(
+            application, self.storage
+        )
+        application = dnsmiddleware.SerializationMiddleware(
             application, dnsutils.TsigKeyring(self.storage)
         )
 
