@@ -49,7 +49,7 @@ CONF.import_opt('storage_driver', 'designate.central',
                 group='service:central')
 CONF.import_opt('auth_strategy', 'designate.api',
                 group='service:api')
-CONF.import_opt('connection', 'designate.storage.impl_sqlalchemy',
+CONF.import_opt('connection', 'designate.storage.sqlalchemy',
                 group='storage:sqlalchemy')
 CONF.import_opt('emitter_type', 'designate.heartbeat_emitter',
                 group="heartbeat_emitter")
@@ -397,8 +397,7 @@ class TestCase(base.BaseTestCase):
         self.admin_context = self.get_admin_context()
         self.admin_context_all_tenants = self.get_admin_context(
             all_tenants=True)
-        storage_driver = CONF['service:central'].storage_driver
-        self.storage = storage.get_storage(storage_driver)
+        self.storage = storage.get_storage()
 
         # Setup the Default Pool with some useful settings
         self._setup_default_pool()
@@ -820,7 +819,7 @@ class TestCase(base.BaseTestCase):
            Zone imports spawn a thread to parse the zone file and
            insert the data. This waits for this process before continuing
         """
-        start_time = time.time()
+        start_time = time.monotonic()
         while True:
             # Retrieve it, and ensure it's the same
             zone_import = self.central_service.get_zone_import(
@@ -835,7 +834,7 @@ class TestCase(base.BaseTestCase):
             if error_is_ok and zone_import.status != 'PENDING':
                 break
 
-            if (time.time() - start_time) > max_wait:
+            if (time.monotonic() - start_time) > max_wait:
                 break
 
             time.sleep(0.5)
@@ -870,8 +869,8 @@ class TestCase(base.BaseTestCase):
         Poll every `interval` seconds.  `condition` can be a callable.
         (Caution: some mocks behave both as values and callables.)
         """
-        t_max = time.time() + timeout
-        while time.time() < t_max:
+        t_max = time.monotonic() + timeout
+        while time.monotonic() < t_max:
             if callable(condition):
                 result = condition()
             else:
