@@ -29,6 +29,7 @@ import designate.central.service
 from designate.central.service import Service
 from designate import exceptions
 from designate import objects
+from designate.storage import sqlalchemy
 from designate.tests.fixtures import random_seed
 from designate.tests import TestCase
 
@@ -179,6 +180,7 @@ class MockRecordSet(object):
     ttl = 1
     type = "PRIMARY"
     serial = 123
+    records = []
 
     def obj_attr_is_set(self, n):
         if n == 'records':
@@ -222,7 +224,7 @@ class CentralBasic(TestCase):
         super(CentralBasic, self).setUp()
         self.CONF = self.useFixture(cfg_fixture.Config(cfg.CONF)).conf
         self.CONF([], project='designate')
-        mock_storage = mock.Mock(spec=designate.storage.base.Storage)
+        mock_storage = mock.Mock(spec=sqlalchemy.SQLAlchemyStorage)
 
         pool_list = objects.PoolList.from_list(
             [
@@ -418,8 +420,9 @@ class CentralServiceTestCase(CentralBasic):
         central_service._is_valid_ttl = mock.Mock()
 
         central_service.storage.create_recordset = mock.Mock(return_value='rs')
-        central_service._update_zone_in_storage = mock.Mock()
-
+        central_service._update_zone_in_storage = mock.Mock(
+            return_value=Mockzone()
+        )
         recordset = mock.Mock(spec=objects.RecordSet)
         recordset.obj_attr_is_set.return_value = True
         recordset.records = [MockRecord()]
@@ -440,7 +443,9 @@ class CentralServiceTestCase(CentralBasic):
         self.service._is_valid_ttl = mock.Mock()
 
         self.service.storage.create_recordset = mock.Mock(return_value='rs')
-        self.service._update_zone_in_storage = mock.Mock()
+        self.service._update_zone_in_storage = mock.Mock(
+            return_value=Mockzone()
+        )
 
         # NOTE(thirose): Since this is a race condition we assume that
         #  we will hit it if we try to do the operations in a loop 100 times.
@@ -560,32 +565,44 @@ class CentralZoneTestCase(CentralBasic):
 
     def test_is_valid_zone_name_invalid(self):
         self.service._is_blacklisted_zone_name = mock.Mock()
-        with testtools.ExpectedException(exceptions.InvalidZoneName):
-            self.service._is_valid_zone_name(self.context,
-                                             'example^org.')
+        self.assertRaisesRegex(
+            exceptions.InvalidZoneName,
+            'More than one label is required',
+            self.service._is_valid_zone_name, self.context, 'example^org.'
+        )
 
     def test_is_valid_zone_name_invalid_2(self):
         self.service._is_blacklisted_zone_name = mock.Mock()
-        with testtools.ExpectedException(exceptions.InvalidZoneName):
-            self.service._is_valid_zone_name(self.context,
-                                             'example.tld.')
+        self.assertRaisesRegex(
+            exceptions.InvalidZoneName,
+            'Invalid TLD',
+            self.service._is_valid_zone_name, self.context, 'example.tld.'
+        )
 
     def test_is_valid_zone_name_invalid_same_as_tld(self):
         self.service._is_blacklisted_zone_name = mock.Mock()
-        with testtools.ExpectedException(exceptions.InvalidZoneName):
-            self.service._is_valid_zone_name(self.context, 'com.com.')
+        self.assertRaisesRegex(
+            exceptions.InvalidZoneName,
+            'Invalid TLD',
+            self.service._is_valid_zone_name, self.context, 'com.com.'
+        )
 
     def test_is_valid_zone_name_invalid_tld(self):
         self.service._is_blacklisted_zone_name = mock.Mock()
-        with testtools.ExpectedException(exceptions.InvalidZoneName):
-            self.service._is_valid_zone_name(self.context, 'tld.')
+        self.assertRaisesRegex(
+            exceptions.InvalidZoneName,
+            'More than one label is required',
+            self.service._is_valid_zone_name, self.context, 'tld.'
+        )
 
     def test_is_valid_zone_name_blacklisted(self):
         self.service._is_blacklisted_zone_name = mock.Mock(
             side_effect=exceptions.InvalidZoneName)
-        with testtools.ExpectedException(exceptions.InvalidZoneName):
-            self.service._is_valid_zone_name(self.context,
-                                             'valid.com.')
+        self.assertRaisesRegex(
+            exceptions.InvalidZoneName,
+            'Invalid TLD',
+            self.service._is_valid_zone_name, self.context, 'valid.com.'
+        )
 
     def test_is_blacklisted_zone_name(self):
         self.service.storage.find_blacklists.return_value = [
@@ -1039,7 +1056,7 @@ class CentralZoneTestCase(CentralBasic):
             name='example.org.',
             tenant_id='2',
             type='SECONDARY',
-            masters=[RoObject(host='10.0.0.1', port=53)],
+            masters=[RoObject(host='192.0.2.1', port=53)],
             serial=1,
         )
         with fx_worker:
@@ -1506,8 +1523,6 @@ class CentralZoneTestCase(CentralBasic):
             self.service.delete_recordset(self.context,
                 CentralZoneTestCase.zone__id_2,
                 CentralZoneTestCase.recordset__id)
-            self.assertTrue(
-                self.service.worker_api.update_zone.called)
 
         self.assertTrue(
             self.service._delete_recordset_in_storage.called)
@@ -1524,6 +1539,7 @@ class CentralZoneTestCase(CentralBasic):
                     action='',
                     status='',
                     serial=0,
+                    increment_serial=False,
                 )
             ])
         )
@@ -1533,7 +1549,7 @@ class CentralZoneTestCase(CentralBasic):
         self.assertEqual(1, len(rs.records))
         self.assertEqual('DELETE', rs.records[0].action)
         self.assertEqual('PENDING', rs.records[0].status)
-        self.assertEqual(1, rs.records[0].serial)
+        self.assertTrue(rs.records[0].serial, 1)
 
     def test_delete_recordset_in_storage_no_increment_serial(self):
         self.service._update_zone_in_storage = mock.Mock()
@@ -1606,6 +1622,42 @@ class CentralZoneTestCase(CentralBasic):
             refresh_time = central_service._generate_soa_refresh_interval()
             self.assertEqual(3563, refresh_time)
 
+    @patch.object(objects.Zone, 'obj_reset_changes')
+    def test_create_secondary_zone(self, mock_obj_reset_changes):
+        self.service._enforce_zone_quota = mock.Mock()
+        self.service._create_zone_in_storage = mock.Mock(
+            return_value=objects.Zone(name='example.com.', type='SECONDARY'))
+        self.service._is_valid_zone_name = mock.Mock()
+        self.service._is_valid_ttl = mock.Mock()
+        self.service._is_subzone = mock.Mock(return_value=False)
+        self.service._is_superzone = mock.Mock(return_value=[])
+        self.service.storage.get_pool.return_value = RoObject(
+            ns_records=[RoObject()])
+        self.useFixture(
+            fixtures.MockPatchObject(
+                self.service.storage,
+                'find_pools',
+                return_value=objects.PoolList.from_list(
+                    [
+                        {'id': '94ccc2c1-d751-44fe-b57f-8894c9f5c842'}
+                    ]
+                )
+            )
+        )
+        output = self.service.create_zone(
+            self.context,
+            objects.Zone(
+                tenant_id='1',
+                name='example.com.',
+                ttl=60,
+                pool_id=CentralZoneTestCase.pool__id,
+                refresh=0,
+                type='SECONDARY'
+            )
+        )
+        self.assertEqual('example.com.', output.name)
+        mock_obj_reset_changes.assert_called_once_with(recursive=True)
+
 
 class IsSubzoneTestCase(CentralBasic):
     def setUp(self):
@@ -1729,6 +1781,20 @@ class CentralZoneExportTests(CentralBasic):
             designate.central.service.policy.check.call_args[0])
         self.assertEqual('find_zone_exports', pcheck)
 
+    def test_find_zone_exports_with_custom_criterion(self):
+        self.context = mock.Mock()
+        self.context.project_id = 't'
+        self.service.storage.find_zone_exports = mock.Mock()
+
+        self.service.find_zone_exports(
+            self.context, criterion={'project_id': 't'}
+        )
+
+        self.assertTrue(self.service.storage.find_zone_exports.called)
+        pcheck, ctx, target = (
+            designate.central.service.policy.check.call_args[0])
+        self.assertEqual('find_zone_exports', pcheck)
+
     def test_delete_zone_export(self):
         self.context = mock.Mock()
         self.context.project_id = 't'
